@@ -31,10 +31,6 @@ add_footer_proc do
 	end
 end
 
-def comment_form_mobile_mail_field
-	%Q|<INPUT NAME="mail" TYPE="hidden">|
-end
-
 add_conf_proc( 'hide-mail-field', @hide_mail_field_label_conf, 'security' ) do
 	if @mode == 'saveconf'
 		@conf['comment_description'] = @cgi.params['comment_description'][0]
