@@ -1,4 +1,4 @@
-$:.unshift File.expand_path(File.join(File.dirname(__FILE__), '..')).untaint
+$:.unshift File.expand_path(File.join(File.dirname(__FILE__), '..'))
 
 ENV['RACK_ENV'] = "test"
 
